@@ -9,17 +9,30 @@ def print_with_time(string):
 
 
 def silent(mode='all'):
-    assert(mode in ['out', 'err', 'all'])
     def silencer(fn):
         def wrapped(*args, **kwargs):
             oo, oe = sys.stdout, sys.stderr
             with open(os.devnull, 'w') as devnull:
-                if mode=='out' or mode=='all':
+                if mode=='out':
                     sys.stdout = devnull
-                if mode=='err' or mode=='all':
+                    ret = fn(*args, **kwargs)
+                    sys.stdout = oo
+                elif mode=='err':
                     sys.stderr = devnull
-                ret = fn(*args, **kwargs)
-            sys.stdout, sys.stderr = oo, oe
+                    ret = fn(*args, **kwargs)
+                    sys.stderr = oo
+                elif mode=='all':
+                    sys.stdout = devnull
+                    sys.stderr = devnull
+                    ret = fn(*args, **kwargs)
+                    sys.stdout, sys.stderr = oo, oe
+                elif mode=='warn':
+                    import warnings
+                    with warnings.catch_warnings():
+                        warnings.simplefilter('ignore')
+                        ret = fn(*args, **kwargs)
+                else:
+                    raise(ValueError("mode should be in ['out', 'err', 'all', 'warn']"))
             return ret
         return wrapped
     return silencer
